@@ -8,7 +8,7 @@
 
 use crate::messaging::{
     data::ServiceMsg,
-    node::{NodeCmd, NodeQuery, NodeQueryResponse},
+    system::{NodeCmd, NodeQuery, NodeQueryResponse},
     AuthorityProof, DstLocation, EndUser, MessageId, ServiceAuth, SrcLocation,
 };
 use bls::PublicKey as BlsPublicKey;
@@ -122,6 +122,8 @@ pub enum Event {
         /// Its xorname is derived from the client public key,
         /// and the socket_id maps against the actual socketaddr
         user: EndUser,
+        /// DstLocation for the message
+        dst_location: DstLocation,
     },
     /// Notify the current list of adult nodes, in case of churning.
     AdultsChanged {
@@ -148,12 +150,4 @@ pub enum MessageReceived {
         /// ID of causing query.
         correlation_id: MessageId,
     },
-    /// The returned error, from any msg handling on recipient node.
-    NodeMsgError {
-        /// The error.
-        // TODO: return node::Error instead
-        error: crate::messaging::data::Error,
-        /// ID of causing cmd.
-        correlation_id: MessageId,
-    },
 }
